/**
*   Please feel free to use any fragment of the code in this file that you need
*   in your own work. As far as I am concerned, it's in the public domain. No
*   permission is necessary or required. Credit is always appreciated if you
*   use a large chunk or base a significant product on one of my examples,
*   but that's not required either.
*
*   This code is distributed in the hope that it will be useful,
*   but WITHOUT ANY WARRANTY; without even the implied warranty of
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
*
*      --- Joseph A. Huwaldt
**/

import java.awt.Component;
import javax.swing.JOptionPane;

import javax.measure.quantity.Dimensionless;

import jahuwaldt.js.param.Parameter;
import jahuwaldt.js.ParamTools.*;


/**
*  Verifies that the input value for the gas specific heat ratio is reasonable.
*
*  <p>  Modified by:  Joseph A. Huwaldt   </p>
*
*  @author   Joseph A. Huwaldt  Date: November 1, 2004
*  @version  December 16, 2023
**/
public class GammaVerifier implements ParamVerifier {
	
	/**
	*  Check to see if the input value is valid for this parameter.
	*
	*  @param   root   The root component containing the parameter input text field
	*                  for the parameter being verified.
	*  @param   value  The value of the parameter as input by the user.
	*  @return  If "value" is valid, it should be output.  If "value" is invalid or
	*           out of range, a valid value is output or Float.NaN if nothing else.
	*           If ParamInput (which calls this routine) recieves a value of Float.NaN,
	*           it will clear the parameter.
	**/
    @Override
	public Parameter check(Component root, Parameter value) {
		Parameter outValue = value;
		
		if (outValue.getValue() <= 1) {
			outValue = Parameter.valueOf(Double.NaN, Dimensionless.UNIT);
			
			JOptionPane.showMessageDialog ( root,
                                "The ratio of specific heats must be > 1.",
								"Out of Range",
								JOptionPane.ERROR_MESSAGE );
		}
		
		return outValue;
	}

}
